@@ -19,7 +19,7 @@ OC.L10N.register(
     "%1$s, %2$s and %3$s" : "%1$s, %2$s och %3$s",
     "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s och %4$s",
     "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s och %5$s",
-    "Education Edition" : "Utbildningspaket",
+    "Education bundle" : "Utbildningspaket",
     "Enterprise bundle" : "Företagspaketet",
     "Groupware bundle" : "Gruppvarupaket",
     "Hub bundle" : "Hub-paket",
@@ -38,16 +38,17 @@ OC.L10N.register(
     "Server version %s or higher is required." : "Serverversion %s eller nyare krävs.",
     "Server version %s or lower is required." : "Serverversion %s eller äldre krävs.",
     "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "Inloggat konto måste vara en admin, underadministratör eller ha tilldelats speciella rättigheter för att komma åt denna inställning",
+    "Your current IP address doesn't allow you to perform admin actions" : "Din nuvarande IP-adress tillåter dig inte att utföra administratörsåtgärder",
     "Logged in account must be an admin or sub admin" : "Inloggat konto måste vara en admin eller underadministratör",
     "Logged in account must be an admin" : "Inloggat konto måste vara admin",
     "Wiping of device %s has started" : "Rensning av enhet %s har startat",
-    "Wiping of device »%s« has started" : "Rensning av enhet »%s« har startat",
-    "»%s« started remote wipe" : "»%s« startade fjärrensning",
-    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "Enhet eller applikation »%s« har startat fjärrensning. Du kommer att få ett nytt mail när processen är klar",
+    "Wiping of device »%s« has started" : "Rensning av enhet \"%s\" har startat",
+    "»%s« started remote wipe" : "\"%s\" startade fjärrensning",
+    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "Enhet eller applikation \"%s\" har startat fjärrensning. Du kommer att få ett nytt mail när processen är klar",
     "Wiping of device %s has finished" : "Rensning av enhet %s har slutförts",
-    "Wiping of device »%s« has finished" : "Rensning av enhet »%s« har slutförts",
-    "»%s« finished remote wipe" : "»%s« slutförde fjärrensning",
-    "Device or application »%s« has finished the remote wipe process." : "Enhet eller applikation »%s« har slutfört fjärrensning.",
+    "Wiping of device »%s« has finished" : "Rensning av enhet \"%s\" har slutförts",
+    "»%s« finished remote wipe" : "\"%s\" slutförde fjärrensning",
+    "Device or application »%s« has finished the remote wipe process." : "Enhet eller applikation \"%s\" har slutfört fjärrensning.",
     "Remote wipe started" : "Fjärrensning startad",
     "A remote wipe was started on device %s" : "Fjärrensning startades på enhet %s",
     "Remote wipe finished" : "Fjärrensning klar",
@@ -58,6 +59,11 @@ OC.L10N.register(
     "Avatar image is not square" : "Profilbilden är inte fyrkantig",
     "Files" : "Filer",
     "View profile" : "Visa profil",
+    "same time" : "samma tid",
+    "_%nh_::_%nh_" : ["%nt","%nt"],
+    "_%nm_::_%nm_" : ["%nm","%nm"],
+    "%s ahead" : "%s före",
+    "%s behind" : "%s efter",
     "Local time: %s" : "Lokal tid: %s",
     "today" : "idag",
     "tomorrow" : "imorgon",
@@ -80,14 +86,36 @@ OC.L10N.register(
     "seconds ago" : "sekunder sedan",
     "Empty file" : "Tom fil",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Modulen med ID: %s finns inte. Aktivera den i appinställningar eller kontakta din administratör.",
+    "No file conversion providers available" : "Ingen filkonverterare tillgänglig",
+    "File is too large to convert" : "Filen är för stor för att konverteras",
+    "Destination does not match conversion extension" : "Målet matchar inte konverteringsändelsen",
+    "Could not convert file" : "Kunde inte konvertera filen",
+    "Destination does not exist" : "Destinationen finns inte",
+    "Destination is not creatable" : "Destinationen går inte att skapa",
+    "Dot files are not allowed" : "Dot-filer är inte tillåtna",
+    "%1$s (renamed)" : "%1$s (omdöpt)",
+    "renamed file" : "omdöpt fil",
+    "\"%1$s\" is a forbidden file or folder name." : "\"%1$s\" är ett förbjudet fil- eller mappnamn.",
+    "\"%1$s\" is a forbidden prefix for file or folder names." : "\"%1$s\" är ett förbjudet prefix för fil- eller mappnamn.",
+    "\"%1$s\" is not allowed inside a file or folder name." : "\"%1$s\" är inte tillåtet i ett fil- eller mappnamn.",
+    "\"%1$s\" is a forbidden file type." : "\"%1$s\" är en förbjuden filtyp.",
+    "Filenames must not end with \"%1$s\"." : "Filnamn får inte sluta med \"%1$s\".",
+    "Invalid parent path" : "Ogiltig överordnad sökväg",
     "File already exists" : "Filen existerar redan",
     "Invalid path" : "Ogiltig sökväg",
     "Failed to create file from template" : "Kunde skapa fil från mall",
     "Templates" : "Mallar",
-    "File name is a reserved word" : "Filnamnet är ett reserverat ord",
-    "File name contains at least one invalid character" : "Filnamnet innehåller minst ett ogiltigt tecken",
-    "File name is too long" : "Filnamnet är för långt",
-    "Dot files are not allowed" : "Dot-filer är inte tillåtna",
+    "Storage %s cannot be moved" : "Lagring %s kan inte flyttas",
+    "Moving a share (%s) into a shared folder is not allowed" : "Att flytta en delning (%s) till en delad mapp är inte tillåtet",
+    "Moving a storage (%s) into a shared folder is not allowed" : "Att flytta en lagring (%s) till en delad mapp är inte tillåtet",
+    "Moving a share (%s) into another share (%s) is not allowed" : "Att flytta en delning (%s) till en annan delning (%s) är inte tillåtet",
+    "Moving a share (%s) into another storage (%s) is not allowed" : "Att flytta en delning (%s) till en annan lagring (%s) är inte tillåtet",
+    "Moving a storage (%s) into a share (%s) is not allowed" : "Att flytta en lagring (%s) till en delning (%s) är inte tillåtet",
+    "Moving a storage (%s) into another storage (%s) is not allowed" : "Att flytta en lagring (%s) till en annan lagring (%s) är inte tillåtet",
+    "Path contains invalid segments" : "Sökvägen innehåller ogiltiga segment",
+    "Filename is a reserved word" : "Filnamnet är ett reserverat ord",
+    "Filename contains at least one invalid character" : "Filnamnet innehåller minst ett ogiltigt tecken",
+    "Filename is too long" : "Filnamnet är för långt",
     "Empty filename is not allowed" : "Tomma filnamn är inte tillåtna",
     "App \"%s\" cannot be installed because appinfo file cannot be read." : "Appen \"%s\" kan inte installeras eftersom appinfo-filen inte kan läsas.",
     "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Appen \"%s\" kan inte installeras eftersom den inte är kompatibel med den här versionen av servern.",
@@ -100,7 +128,8 @@ OC.L10N.register(
     "Administration settings" : "Administration",
     "Settings" : "Inställningar",
     "Log out" : "Logga ut",
-    "Users" : "Användare",
+    "Accounts" : "Konton",
+    "Bluesky" : "Bluesky",
     "Email" : "E-post",
     "Mail %s" : "Skicka e-post %s",
     "Fediverse" : "Fediverse",
@@ -116,8 +145,9 @@ OC.L10N.register(
     "About" : "Om",
     "Display name" : "Visningsnamn",
     "Headline" : "Rubrik",
-    "Organisation" : "Organisation",
+    "Organization" : "Organisering",
     "Role" : "Roll",
+    "Pronouns" : "Pronomen",
     "Unknown account" : "Okänt konto",
     "Additional settings" : "Övriga inställningar",
     "Enter the database Login and name for %s" : "Ange databas-inloggning och namn för %s",
@@ -129,7 +159,7 @@ OC.L10N.register(
     "Oracle connection could not be established" : "Oracle-anslutning kunde inte etableras",
     "Oracle Login and/or password not valid" : "Oracle-inloggning och/eller lösenord är felaktigt",
     "PostgreSQL Login and/or password not valid" : "PostgreSQL-inloggning och/eller lösenord är felaktigt",
-    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X stöds inte och %s kommer inte att fungera korrekt på denna plattform. Använd på egen risk!",
+    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk!" : "Mac OS X stöds inte och %s kommer inte att fungera korrekt på denna plattform. Använd på egen risk!",
     "For the best results, please consider using a GNU/Linux server instead." : "För bästa resultat, överväg att använda en GNU/Linux-server istället.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Det verkar som om denna %s instans körs på en 32-bitars PHP miljö och open_basedir har konfigurerats i php.ini. Detta kommer att leda till problem med filer över 4 GB och är verkligen inte rekommenderat!",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Ta bort open_basedir-inställningen i din php.ini eller växla till 64-bitars PHP.",
@@ -139,26 +169,61 @@ OC.L10N.register(
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Delningsgränssnittet %s måste implementera gränssnittet OCP\\Share_Backend",
     "Sharing backend %s not found" : "Delningsgränssnittet %s hittades inte",
     "Sharing backend for %s not found" : "Delningsgränssnittet för %s hittades inte",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s delade »%2$s« med dig och vill lägga till:",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$s delade »%2$s« med dig och vill lägga till",
-    "»%s« added a note to a file shared with you" : "»%s« la till en kommentar till en fil delad med dig",
-    "Open »%s«" : "Öppna »%s«",
+    "%1$s shared %2$s with you" : "%1$s delade %2$s med dig",
+    "Open %s" : "Öppna %s",
     "%1$s via %2$s" : "%1$s via %2$s",
+    "%1$s shared %2$s with you and wants to add:" : "%1$s delade %2$s med dig och vill lägga till:",
+    "%1$s shared %2$s with you and wants to add" : "%1$s delade %2$s med dig och vill lägga till",
+    "%s added a note to a file shared with you" : "%s la till en kommentar till en fil delad med dig",
+    "Passwords are enforced for link and mail shares" : "Lösenord är obligatoriskt för länk och e-postdelning",
+    "Share recipient is not a valid user" : "Delningsmottagare är inte en giltig användare",
+    "Share recipient is not a valid group" : "Delningsmottagare är inte en giltig grupp",
+    "Share recipient should be empty" : "Delningsmottagare ska vara tom",
+    "Share recipient should not be empty" : "Delningsmottagare ska inte vara tom",
+    "Share recipient is not a valid circle" : "Delningsmottagare är inte en giltig cirkel",
+    "Unknown share type" : "Ogiltig delningstyp",
+    "Share initiator must be set" : "Initiativtagare för delning måste anges",
+    "Cannot share with yourself" : "Kan inte dela med dig själv",
+    "Shared path must be set" : "Delad sökväg måste anges",
+    "Shared path must be either a file or a folder" : "Delad sökväg måste vara antingen en fil eller en mapp",
+    "You cannot share your root folder" : "Du kan inte dela din rotmapp",
     "You are not allowed to share %s" : "Du tillåts inte att dela %s",
+    "Valid permissions are required for sharing" : "Giltiga behörigheter krävs för att dela",
+    "File shares cannot have create or delete permissions" : "Fildelningar kan inte ha behörighet att skapa eller radera",
     "Cannot increase permissions of %s" : "Kan inte höja behörigheter av %s",
+    "Shares need at least read permissions" : "Delningar behöver åtminstone läsbehörighet",
     "Files cannot be shared with delete permissions" : "Filer kan inte delas med rättighet att radera",
     "Files cannot be shared with create permissions" : "Filer kan inte delas med rättighet att skapa",
     "Expiration date is in the past" : "Utgångsdatum är i det förflutna",
+    "Expiration date is enforced" : "Förfallodatum är obligatoriskt",
     "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Kan inte sätta ett utgångsdatum längre fram än %n dag","Kan inte sätta ett utgångsdatum längre fram än %n dagar"],
     "Sharing is only allowed with group members" : "Delning är endast tillåten med gruppmedlemmar",
     "Sharing %s failed, because this item is already shared with the account %s" : "Delning av %s misslyckades, eftersom det här objektet redan delas med kontot %s",
-    "%1$s shared »%2$s« with you" : "%1$s delade »%2$s« med dig",
-    "%1$s shared »%2$s« with you." : "%1$s delade »%2$s« med dig.",
-    "Click the button below to open it." : "Klicka på knappen nedan för att öppna det.",
+    "Group sharing is now allowed" : "Gruppdelning är nu tillåten",
+    "Sharing is only allowed within your own groups" : "Delning är endast tillåten inom dina egna grupper",
+    "Path is already shared with this group" : "Sökvägen delas redan med den här gruppen",
+    "Link sharing is not allowed" : "Länkdelning är inte tillåtet",
+    "Public upload is not allowed" : "Offentlig uppladdning är inte tillåten",
+    "You cannot share a folder that contains other shares" : "Du kan inte dela en mapp som innehåller andra delningar",
+    "Sharing is disabled" : "Delning är inaktiverat",
+    "Sharing is disabled for you" : "Delning är inaktiverat för dig",
+    "Cannot share with the share owner" : "Kan inte dela med ägaren",
+    "Share does not have a full ID" : "Delningen har inte ett fullständigt ID",
+    "Cannot change share type" : "Kan inte ändra delningstyp",
+    "Can only update recipient on user shares" : "Kan bara uppdatera mottagare på användardelningar",
+    "Cannot enable sending the password by Talk with an empty password" : "Kan inte aktivera sändning av lösenordet via Talk med ett tomt lösenord",
+    "Cannot enable sending the password by Talk without setting a new password" : "Kan inte aktivera sändning av lösenordet med Talk utan att ange ett nytt lösenord",
+    "Cannot disable sending the password by Talk without setting a new password" : "Kan inte inaktivera sändning av lösenordet med Talk utan att ange ett nytt lösenord",
+    "Share provider does not support accepting" : "Delningsleverantör stöder inte acceptans",
+    "Cannot change target of link share" : "Kan inte ändra mål för länkdelning",
+    "Invalid share recipient" : "Ogiltig delningsmottagare",
+    "Group \"%s\" does not exist" : "Gruppen \"%s\" finns inte",
     "The requested share does not exist anymore" : "Den begärda delningen finns inte mer",
     "The requested share comes from a disabled user" : "Den begärda delningen kommer från en inaktiverad användare",
     "The user was not created because the user limit has been reached. Check your notifications to learn more." : "Användaren skapades inte eftersom användargränsen har nåtts. Kontrollera dina aviseringar för att läsa mer.",
     "Could not find category \"%s\"" : "Kunde inte hitta kategorin \"%s\"",
+    "Input text" : "Mata in text",
+    "The input text" : "Inmatningstexten",
     "Sunday" : "Söndag",
     "Monday" : "Måndag",
     "Tuesday" : "Tisdag",
@@ -211,13 +276,12 @@ OC.L10N.register(
     "A valid Login must be provided" : "En giltig inloggning måste anges",
     "Login contains whitespace at the beginning or at the end" : "Inloggningen innehåller blanksteg i början eller slutet",
     "Login must not consist of dots only" : "Inloggningen får inte innehålla enbart punkter",
+    "Username is too long" : "Användarnamnet är för långt",
     "Login is invalid because files already exist for this user" : "Inloggningen är ogiltigt eftersom det redan finns filer för den här användaren",
     "Account disabled" : "Konto inaktiverat",
     "Login canceled by app" : "Inloggningen avbruten av appen",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Appen \"%1$s\" kan inte installeras eftersom följande beroenden inte är uppfyllda: %2$s",
     "a safe home for all your data" : "ett säkert hem för all din data",
-    "File is currently busy, please try again later" : "Filen är för tillfället upptagen, försök igen senare",
-    "Cannot download file" : "Kan inte ladda ner fil",
     "Application is not enabled" : "Applikationen är inte aktiverad",
     "Authentication error" : "Fel vid autentisering",
     "Token expired. Please reload page." : "Token har löpt ut. Uppdatera sidan.",
@@ -225,8 +289,6 @@ OC.L10N.register(
     "Cannot write into \"config\" directory." : "Kan inte skriva i \"config\"-katalogen.",
     "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Detta kan vanligtvis åtgärdas genom att ge webbservern skrivåtkomst till config-katalogen. Se %s",
     "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Eller, om du föredrar att behålla config.php skrivskyddad, sätt alternativet \"config_is_read_only\" till true i den. Se %s",
-    "Cannot write into \"apps\" directory." : "Kan inte skriva till \"apps\"-katalogen.",
-    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Detta kan vanligtvis åtgärdas genom att ge webbservern skrivrättigheter till \"apps\"-katalogen eller stänga av appbutiken i konfigurationsfilen.",
     "Cannot create \"data\" directory." : "Kan inte skapa \"data\"-katalog.",
     "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Detta kan vanligtvis åtgärdas genom att ge webbservern skrivåtkomst till rotkatalogen. Se %s",
     "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Behörigheter kan vanligtvis fixas genom att ge webbservern skrivåtkomst till rotkatalogen. Se %s.",
@@ -237,8 +299,6 @@ OC.L10N.register(
     "Please ask your server administrator to install the module." : "Be serveradministratören att installera modulen.",
     "PHP setting \"%s\" is not set to \"%s\"." : "PHP-inställning \"%s\" är inte inställd på \"%s\".",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "Att ändra denna inställning i php.ini kommer göra så att Nextcloud fungerar igen",
-    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> är satt till <code>%s</code> istället för förväntade värdet <code>0</code>.",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : " För att åtgärda detta problemet, sätt<code>mbstring.func_overload</code> till <code>0</code> i din php.ini.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP är tydligen inställt för att tömma \"inline doc blocks\". Detta kommer att göra flera kärnprogram otillgängliga.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Detta orsakas troligtvis av en cache/accelerator som t ex Zend OPchache eller eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP-moduler har installerats, men de listas fortfarande som saknade?",
@@ -250,7 +310,7 @@ OC.L10N.register(
     "Your data directory must be an absolute path." : "Din datakatalog måste vara en absolut sökväg.",
     "Check the value of \"datadirectory\" in your configuration." : "Kontrollera värdet på \"datadirectory\" i din konfiguration.",
     "Your data directory is invalid." : "Din datakatalog är ogiltig.",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Säkerställ att du har filen \".ocdata\" i huvudkatalogen för din data.",
+    "Ensure there is a file called \"%1$s\" in the root of the data directory. It should have the content: \"%2$s\"" : "Se till att det finns en fil som heter \"%1$s\" i roten av datakatalogen. Den ska ha innehållet: \"%2$s\"",
     "Action \"%s\" not supported or implemented." : "Åtgärd \"%s\" stöds inte eller är inte implementerad.",
     "Authentication failed, wrong token or provider ID given" : "Autentisering misslyckades, felaktig token eller leverantörs-ID",
     "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Parametrar saknas för att slutföra förfrågan. Saknade parametrar: \"%s\"",
@@ -262,36 +322,140 @@ OC.L10N.register(
     "Storage connection error. %s" : "Lagringsutrymme lyckas inte ansluta. %s",
     "Storage is temporarily not available" : "Lagringsutrymme är för tillfället inte tillgängligt",
     "Storage connection timeout. %s" : "Lagringsutrymme lyckas inte ansluta \"timeout\". %s",
-    "Generate headline" : "Skapa rubrik",
-    "Generates a possible headline for a text." : "Genererar en möjlig rubrik för en text.",
+    "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "För att denna kontroll ska kunna köra måste du se till att webbservern kan ansluta till sig själv. Den måste alltså kunna finna och ansluta till minst en av sina \"trusted_domains\" eller \"overwrite.cli.url\":en. Detta misslyckande kan vara resultatet av en DNS missmatch på serversidan eller utgående brandväggs-regler.",
+    "Images" : "Bilder",
+    "Question" : "Fråga",
+    "Generated response" : "Genererat svar",
+    "System prompt" : "Systemuppmaning",
+    "Define rules and assumptions that the assistant should follow during the conversation." : "Definiera regler och antaganden som assistenten ska följa under samtalet.",
+    "Chat history" : "Chatthistorik",
+    "Transcribe audio" : "Transkribera ljud",
+    "Transcribe the things said in an audio" : "Transkribera det som sägs i ljud",
+    "Audio input" : "Ljudinmatning",
+    "The audio to transcribe" : "Ljudet att transkribera",
+    "Transcription" : "Transkription",
+    "The transcribed text" : "Den transkriberade texten",
+    "Confirmation" : "Bekräftelse",
+    "Whether to confirm previously requested actions: 0 for denial and 1 for confirmation." : "Om tidigare begärda åtgärder ska bekräftas: 0 för avslag och 1 för bekräftelse.",
+    "Conversation token" : "Konversationstoken",
+    "A token representing the conversation." : "En token som representerar konversationen.",
+    "The new conversation token" : "Den nya konversationstoken",
+    "Send this along with the next interaction." : "Skicka detta tillsammans med nästa interaktion.",
+    "Requested actions by the agent" : "Begärda åtgärder av agenten",
+    "Actions that the agent would like to carry out in JSON format." : "Åtgärder som agenten vill utföra i JSON-format.",
+    "Chat with an agent" : "Chatta med en agent",
+    "Chat message" : "Chattmeddelande",
+    "A chat message to send to the agent." : "Ett chattmeddelande att skicka till agenten.",
+    "The response from the chat model." : "Svaret från chattmodellen.",
+    "Context write" : "Kontextuell skrivning",
+    "Writes text in a given style based on the provided source material." : "Skriver text i en given stil baserat på det tillhandahållna källmaterialet.",
+    "Writing style" : "Skrivstil",
+    "Demonstrate a writing style that you would like to immitate" : "Demonstrera en skrivstil som du skulle vilja imitera",
+    "Source material" : "Källmaterial",
+    "The content that would like to be rewritten in the new writing style" : "Innehållet som skulle vilja skrivas om i den nya skrivstilen",
+    "Generated text" : "Genererad text",
+    "The generated text with content from the source material in the given style" : "Den genererade texten med innehåll från källmaterialet i den givna stilen",
+    "Emoji generator" : "Emoji-generator",
+    "Takes text and generates a representative emoji for it." : "Tar text och genererar en representativ emoji för den.",
+    "The text to generate an emoji for" : "Texten att generera en emoji för",
+    "Generated emoji" : "Genererad emoji",
+    "The generated emoji based on the input text" : "Den genererade emojin baserad på inmatningstexten",
+    "Generate image" : "Skapa bild",
+    "Generate an image from a text prompt" : "Skapa en bild från en textuppmaning",
+    "Prompt" : "Uppmaning",
+    "Describe the image you want to generate" : "Beskriv bilden du vill skapa",
+    "Number of images" : "Antal bilder",
+    "How many images to generate" : "Hur många bilder som ska genereras",
+    "Output images" : "Skapade bilder",
+    "The generated images" : "De genererade bilderna",
+    "Generate speech" : "Generera tal",
+    "Generate speech from a transcript" : "Generera tal från en transkription",
+    "Write transcript that you want the assistant to generate speech from" : "Skriv den transkription som du vill att assistenten ska generera tal från",
+    "Output speech" : "Genererat tal",
+    "The generated speech" : "Det genererade talet",
+    "Free text to text prompt" : "Fritext till text prompt",
+    "Runs an arbitrary prompt through a language model that returns a reply" : "Kör en godtycklig prompt genom en språkmodell som returnerar ett svar",
+    "Describe a task that you want the assistant to do or ask a question" : "Beskriv en uppgift som du vill att assistenten ska göra eller ställ en fråga",
+    "Generated reply" : "Genererat svar",
+    "The generated text from the assistant" : "Den genererade texten från assistenten",
+    "Change Tone" : "Ändra tonfall",
+    "Change the tone of a piece of text." : "Ändra tonfallet i ett stycke text.",
+    "Write a text that you want the assistant to rewrite in another tone." : "Skriv text som du vill att assistenten ska omformulera med ett annat tonfall.",
+    "Desired tone" : "Önskat tonfall",
+    "In which tone should your text be rewritten?" : "I vilken ton ska din text skrivas om?",
+    "The rewritten text in the desired tone, written by the assistant:" : "Den omskrivna texten i önskad ton, skriven av assistenten:",
+    "Chat" : "Chatt",
+    "Chat with the assistant" : "Chatta med assistenten",
+    "The history of chat messages before the current message, starting with a message by the user" : "Historiken för chattmeddelanden före det aktuella meddelandet, som börjar med ett meddelande från användaren",
+    "Response message" : "Svarsmeddelande",
+    "The generated response as part of the conversation" : "Det genererade svaret som en del av konversationen",
+    "Chat with tools" : "Chatt med verktyg",
+    "Chat with the language model with tool calling support." : "Chatt med språkmodellen med stöd för verktygsanrop.",
+    "Tool message" : "Verktygsmeddelande",
+    "The result of tool calls in the last interaction" : "Resultatet av verktygsanropen i den senaste interaktionen",
+    "Available tools" : "Tillgängliga verktyg",
+    "The available tools in JSON format" : "Tillgängliga verktyg i JSON-format",
+    "The response from the chat model" : "Svaret från chattmodellen",
+    "Tool calls" : "Verktagsanrop",
+    "Tools call instructions from the model in JSON format" : "Verktygsanrop och instruktioner från modellen i JSON-format",
+    "Formalize text" : "Formalisera text",
+    "Takes a text and makes it sound more formal" : "Tar en text och får det att låta mer formellt",
+    "Write a text that you want the assistant to formalize" : "Skriv en text som du vill att assistenten ska formalisera",
+    "Formalized text" : "Formaliserad text",
+    "The formalized text" : "Den formaliserade texten",
+    "Generate a headline" : "Skapa en rubrik",
+    "Generates a possible headline for a text." : "Skapar en möjlig rubrik för en text.",
+    "Original text" : "Ursprunglig text",
+    "The original text to generate a headline for" : "Den ursprungliga texten att skapa en rubrik för",
+    "The generated headline" : "Den skapade rubriken",
+    "Proofread" : "Korrekturläs",
+    "Proofreads a text and lists corrections" : "Korrekturläser en text och listar korrigeringar",
+    "Text" : "Text",
+    "The text to proofread" : "Texten som ska korrekturläsas",
+    "Corrections" : "Korrigeringar",
+    "The corrections that should be made in your text" : "Korrigeringarna som bör göras i din text",
+    "Reformulate text" : "Omformulera text",
+    "Takes a text and reformulates it" : "Tar en text och omformulerar den",
+    "Write a text that you want the assistant to reformulate" : "Skriv en text som du vill att assistenten ska formulera om",
+    "Reformulated text" : "Omformulerad text",
+    "The reformulated text, written by the assistant" : "Den omformulerade texten, skriven av assistenten",
+    "Simplify text" : "Förenkla text",
+    "Takes a text and simplifies it" : "Tar en text och förenklar den",
+    "Write a text that you want the assistant to simplify" : "Skriv en text som du vill att assistenten ska förenkla",
+    "Simplified text" : "Förenklad text",
+    "The simplified text" : "Den förenklade texten",
     "Summarize" : "Sammanfatta",
-    "Summarizes text by reducing its length without losing key information." : "Sammanfattar text genom att minska dess längd utan att förlora viktig information.",
+    "Summarizes a text" : "Sammanfattar en text",
+    "The original text to summarize" : "Den ursprungliga texten för att sammanfatta",
+    "Summary" : "Sammanfattning",
+    "The generated summary" : "Den genererade sammanfattningen",
     "Extract topics" : "Extrahera ämnen",
+    "Extracts topics from a text and outputs them separated by commas" : "Extraherar ämnen från en text och matar ut dem separerade med kommatecken",
+    "The original text to extract topics from" : "Originaltexten att extrahera ämnen från",
+    "Topics" : "Ämnen",
+    "The list of extracted topics" : "Listan över extraherade ämnen",
+    "Translate" : "Översätt",
+    "Translate text from one language to another" : "Översätt text från ett språk till ett annat",
+    "Origin text" : "Ursprungstext",
+    "The text to translate" : "Text att översätta",
+    "Origin language" : "Ursprungsspråk",
+    "The language of the origin text" : "Ursprungstextens språk",
+    "Target language" : "Målspråk",
+    "The desired language to translate the origin text in" : "Det önskade språket att översätta ursprungstexten till",
+    "Result" : "Resultat",
+    "The translated text" : "Den översatta texten",
+    "Free prompt" : "Fri prompt",
+    "Runs an arbitrary prompt through the language model." : "Kör en godtycklig uppmaning genom språkmodellen.",
+    "Generate headline" : "Skapa rubrik",
+    "Summarizes text by reducing its length without losing key information." : "Sammanfattar text genom att minska dess längd utan att förlora viktig information.",
     "Extracts topics from a text and outputs them separated by commas." : "Extraherar ämnen från en text och matar ut dem separerade med kommatecken.",
-    "404" : "404",
-    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Inloggad användare måste vara en admin, sub-admin eller ha tilldelats speciella rättigheter för att komma åt denna inställning",
-    "Logged in user must be an admin or sub admin" : "Inloggad användare måste vara administratör eller del-administratör",
-    "Logged in user must be an admin" : "Inloggad användare måste vara administratör",
-    "Help" : "Hjälp",
-    "Unknown user" : "Okänd användare",
-    "Enter the database username and name for %s" : "Ange databasanvändarnamn och lösenord för %s",
-    "Enter the database username for %s" : "Ange databasanvändare för %s",
-    "MySQL username and/or password not valid" : "MySQL-användarnamn och/eller lösenord är felaktigt",
-    "Oracle username and/or password not valid" : "Oracle-användarnamnet och/eller lösenordet är felaktigt",
-    "PostgreSQL username and/or password not valid" : "PostgreSQL-användarnamnet och/eller lösenordet är felaktigt",
-    "Set an admin username." : "Ange ett användarnamn för administratören.",
-    "Sharing %s failed, because this item is already shared with user %s" : "Delning av %s misslyckades eftersom detta redan är delat med användaren %s",
-    "The username is already being used" : "Användarnamnet används redan",
-    "Could not create user" : "Kunde inte skapa användare",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Endast följande tecken är tillåtna i ett användarnamn: \"a-z\", \"A-Z\", \"0-9\", mellanslag och \"_.@-'\"",
-    "A valid username must be provided" : "Ett giltigt användarnamn måste anges",
-    "Username contains whitespace at the beginning or at the end" : "Användarnamnet består av ett mellanslag i början eller i slutet",
-    "Username must not consist of dots only" : "Användarnamnet får inte innehålla enbart punkter",
-    "Username is invalid because files already exist for this user" : "Användarnamnet är ogiltigt eftersom det redan finns filer för den här användaren",
-    "User disabled" : "Användare inaktiverad",
-    "PostgreSQL >= 9 required." : "PostgreSQL >= 9 krävs.",
-    "Please upgrade your database version." : "Uppgradera din databasversion.",
-    "Your data directory is readable by other users." : "Din datakatalog kan läsas av andra användare.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Ändra behörigheterna till 0770 så att katalogen inte kan listas av andra användare."
+    "Organisation" : "Organisation",
+    "File is currently busy, please try again later" : "Filen är för tillfället upptagen, försök igen senare",
+    "Cannot download file" : "Kan inte ladda ner fil",
+    "Cannot write into \"apps\" directory." : "Kan inte skriva till \"apps\"-katalogen.",
+    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Detta kan vanligtvis åtgärdas genom att ge webbservern skrivrättigheter till \"apps\"-katalogen eller stänga av appbutiken i konfigurationsfilen.",
+    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> är satt till <code>%s</code> istället för förväntade värdet <code>0</code>.",
+    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : " För att åtgärda detta problemet, sätt<code>mbstring.func_overload</code> till <code>0</code> i din php.ini.",
+    "Login is too long" : "Inloggningen är för lång"
 },
 "nplurals=2; plural=(n != 1);");
